@@ -11,7 +11,7 @@ class CalendarService:
     def __init__(self,settings):
         import sys
         sys.path.append('../../')
-        from utilities.URLUtility import GenericURL
+        from inhand.utilities.URLUtility import GenericURL
         self.settings = settings
         ssl._create_default_https_context = ssl._create_unverified_context
 
@@ -23,18 +23,61 @@ class CalendarService:
 
     @staticmethod
     def createCalendarService(settings):
-        if settings.app.calendar_provider == 'baidu':
+        #if settings.app.calendar_provider == 'baidu':
+        #    return BaiduCalendarService(settings)
+        if settings.calendar_provider == 'wannianli':
             return BaiduCalendarService(settings)
         else:
             return None
 
 
 
+
+class WanNianLi:
+#    def __init__(self,settings):
+#        CalendarService.__init__(self,settings)
+#        self.calendar_provider = self.settings.calendar_provider
+#        self.calendar_url = self.settings.calendar_url
+
+    def __init__(self,provider,url):
+        self.calendar_provider = provider
+        self.calendar_url = url
+
+
+    # 输入参数：月份
+    # 参考： https://www.mxnzp.com/doc/detail?id=1
+    def query(self, year, month):
+        ym = datetime.now().strftime('%Y%m')
+        if year is not None and month is not None:
+            ym = "{}{}".format(year,str(month).zfill(2))
+        url=self.calendar_url.format(ym)
+        days={}
+        try:
+            r=requests.get(url)
+            f = r.json()
+            for item in f['data']:
+                #type; 类型 0 工作日 1 假日 2 节假日 如果ignoreHoliday参数为true，这个字段不返回
+               days[item['date']] = 1 if item['type'] != 0 else 2
+
+            return days
+
+        except Exception as e:
+            traceback.print_exc()
+            logging.warning("While call %s, There is an exception: %s" % (self.calendar_url, e))
+            return None
+
+
+
+#作废，结果不对
 class BaiduCalendarService(CalendarService):
     def __init__(self,settings):
         CalendarService.__init__(self,settings)
-        self.calendar_provider = self.settings.app.calendar_provider
-        self.calendar_url = self.settings.app.calendar_url
+        self.calendar_provider = self.settings.calendar_provider
+        self.calendar_url = self.settings.calendar_url
+#    def __init__(self,provider,url):
+#        self.calendar_provider = provider
+#        self.calendar_url = url
+
     # 输入参数：月份
     def query(self,year,month):
         url = self.calendar_url
@@ -76,19 +119,22 @@ class BaiduCalendarService(CalendarService):
             dit = dict(map(lambda x, y: [x, int(y)], lst2, lst3))
             return dit
         except Exception as e:
-            logging.warning("While call %s, There is an exception: %s" % (self.url.host,e))
+            traceback.print_exc()
+            logging.warning("While call %s, There is an exception: %s" % (self.calendar_url,e))
             return None
-
+"""
 if __name__ == '__main__':
     import sys
 
-    sys.path.append('../../')
-    from Settings import Settings
-    settings=Settings.readLocalSettings(path="../../../../test.json")
+    #sys.path.append('../../')
+    #from inhand.service.SettingService import SpringCloudSettings
+    #settings=SpringCloudSettings()
+    #settings.readLocalSettings(path="../../../../test.json",module="jx-attendance-stat-svc")
 
-    calcendar = CalendarService.createCalendarService(settings)
-    ret = calcendar.query('2020','09')
+    #calcendar = CalendarService.createCalendarService(settings)
+    calcendar=WanNianLi("wangnianli","https://www.mxnzp.com/api/holiday/list/month/{}?app_id=j89kjqhkrnxtlorm&app_secret=c1lkY0dneElHNDdtQVlZWTRkNjlGZz09")
+    ret = calcendar.query('2022','04')
     print(ret)
-    ret = calcendar.query(2019,9)
+    ret = calcendar.query(2022,4)
     print(ret)
-
+"""
